/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */

/* $Id$ */

/* Copyright (C) 1998-99 Martin Baulig
   This file is part of LibGTop 1.0.

   Contributed by Martin Baulig <martin@home-of-linux.org>, April 1998.

   LibGTop is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License,
   or (at your option) any later version.

   LibGTop is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
   for more details.

   You should have received a copy of the GNU General Public License
   along with LibGTop; see the file COPYING. If not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#include <glibtop.h>
#include <glibtop/error.h>
#include <glibtop/procsignal.h>

static const unsigned long _glibtop_sysdeps_proc_signal =
(1L << GLIBTOP_PROC_SIGNAL_SIGNAL) + (1L << GLIBTOP_PROC_SIGNAL_BLOCKED) +
(1L << GLIBTOP_PROC_SIGNAL_SIGIGNORE) + (1L << GLIBTOP_PROC_SIGNAL_SIGCATCH);

/* Init function. */

int
glibtop_init_proc_signal_s (glibtop *server)
{
    server->sysdeps.proc_signal = _glibtop_sysdeps_proc_signal;

    return 0;
}

/* Provides detailed information about a process. */

int
glibtop_get_proc_signal_s (glibtop *server, glibtop_proc_signal *buf, pid_t pid)
{
    char buffer [BUFSIZ], *p;
	
    glibtop_init_s (&server, GLIBTOP_SYSDEPS_PROC_SIGNAL, 0);

    memset (buf, 0, sizeof (glibtop_proc_signal));

    if (proc_stat_to_buffer (buffer, pid))
	return -1;

    p = proc_stat_after_cmd (buffer);
    if (!p) return -1;

    p = skip_multiple_token (p, 28);

    buf->signal [0] = strtoul (p, &p, 0);
    buf->blocked [0] = strtoul (p, &p, 0);
    buf->sigignore [0] = strtoul (p, &p, 0);
    buf->sigcatch [0] = strtoul (p, &p, 0);

    buf->flags = _glibtop_sysdeps_proc_signal;

    return 0;
}
